conversion

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 20, 2026 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func IntToUint8

func IntToUint8(i int) (uint8, error)

IntToUint8 converts an int to uint8, returning an error if the value is out of range.

func IntToUint16

func IntToUint16(i int) (uint16, error)

IntToUint16 converts an int to uint16, returning an error if the value is out of range.

func IntToUint32

func IntToUint32(i int) (uint32, error)

IntToUint32 converts an int to uint32, returning an error if the value is out of range.

Types

This section is empty.

Jump to