Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IntToUint8 ¶
IntToUint8 converts an int to uint8, returning an error if the value is out of range.
func IntToUint16 ¶
IntToUint16 converts an int to uint16, returning an error if the value is out of range.
func IntToUint32 ¶
IntToUint32 converts an int to uint32, returning an error if the value is out of range.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.